@@ -1,4 +1,4 @@
-from typing import Match
+from math import *
 
 
 def resolveEqFirstDegree(equation):
@@ -34,4 +34,28 @@ def getFormula(expression):
     if formula != "":
         formula = exp + "=" + formula   
     
-    return formula  
\ No newline at end of file
+    return formula  
+def resolveEqSecondDegree(equation):
+    """Resolves a second degree equation
+    The given equation should be in the from of ax²+bx+c=0. 
+    """
+    eq = equation.replace(" ","")
+    posXSquare = eq.find('x²')
+    posX = eq.find('x')
+    posEqual = eq.find('=')
+
+    a = int(eq[0:posXSquare])
+    b = int(eq[posXSquare+1:posX])
+    c = int(eq[posX+1:posEqual])
+
+    solution = []
+    delta = b** -4*a*c
+    if delta == 0:
+        x0 =-b/2*a
+        solution[x0]
+    elif delta > 0:
+        x1=(-b+sqrt(delta))/2*a
+        x2=(-b-sqrt(delta))/2*a
+        solution=[x1,x2]
+
+    return solution 
